@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "immaterial-theme" "0.10.0"
+(define-package "immaterial-theme" "20251222.1352"
   "A family of themes loosely based on material colors."
   '((emacs        "29")
     (modus-themes "5.0.0"))
